library(FSA)
library(propagate)
library(minpack.lm)

#Load data
data<-read.csv("Zuri Pubis LAG spacing.csv", header=TRUE)
data

#Plot
plot(data$LAG.number, data$Pubis.radius..mm., 
     xlab="LAG number at death (age independent)", ylab="Pubis radius estimate (mm)", 
     xlim=c(-10,30), ylim=c(0,25), cex.lab=1.25, pch=1 , col='white')




#### WITH LAG 1 AND PERIOSTEUM

#fit logistic growth model 
x<-as.numeric(data$LAG.number)
y<-as.numeric(data$Pubis.radius..mm.)
logistic.zuri <- nlsLM(y~L/(1+exp(p+k*x)), 
                       start=list(L=25, k=-0.3, p=1.25), data=as.list(data))
logistic.zuri
points(x=seq(from=-20, to=50, by=0.1), 
       y=(18.6591)/(1+exp((0.3949)+(-0.2865)*(seq(from=-20, to=50, by=0.1)))), 
       type="l", col="purple", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model
x<-as.numeric(data$LAG.number)
y<-as.numeric(data$Pubis.radius..mm.)
gompertz.zuri<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), 
                     start=list(i=3,k=0.25,l=18), data=as.list(data))
gompertz.zuri
points(x=seq(from=-20, to=50, by=0.1), 
       y=(19.02630)*2.71828^(-2.71828^(-(0.22558)*(seq(from=-20, to=50, by=0.1)-(-0.06682)))), 
       type="l", col="purple", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit VB growth model
x<-as.numeric(data$LAG.number)
y<-as.numeric(data$Pubis.radius..mm.)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define Von Bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(data),
                  start=list(Linf=18, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), 
       y=(19.6469)*(1-exp(-(0.1646)*((seq(from=-20, to=50, by=0.1))-(-2.4448)))), 
       type="l", col="purple", lwd=2, lty=4) #Insert the parameters found in the model manually

#fit logarithmic growth model 
x<-as.numeric(data$LAG.number)
y<-as.numeric(data$Pubis.radius..mm.)
model.zuri <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.zuri,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='purple', lty=3)




#### WITHOUT LAG 1 AND PERIOSTEUM

data$LAG
dataNO<-subset(data, data$LAG!='Periosteum')
dataNO<-subset(dataNO, dataNO$LAG!='1')
dataNO

#fit logistic growth model 
x<-as.numeric(dataNO$LAG)
y<-as.numeric(dataNO$Pubis.radius..mm.)
logistic.zuriNO <- nlsLM(y~L/(1+exp(p+k*x)), 
                       start=list(L=25, k=-0.3, p=1.25), data=as.list(dataNO))
logistic.zuriNO
points(x=seq(from=-20, to=50, by=0.1), 
       y=(19.1279)/(1+exp((0.2539)+(-0.2398)*(seq(from=-20, to=50, by=0.1)))), 
       type="l", col="orange", lwd=2, lty=1) #Insert the parameters found in the model manually

#fit Gompertz growth model
x<-as.numeric(dataNO$LAG)
y<-as.numeric(dataNO$Pubis.radius..mm.)
gompertz.zuriNO<-nlsLM(y~l*2.71828^(-2.71828^(-k*(x-i))), 
                     start=list(i=3,k=0.25,l=18), data=as.list(dataNO))
gompertz.zuriNO
points(x=seq(from=-20, to=50, by=0.1), 
       y=(19.5935)*2.71828^(-2.71828^(-(0.1885)*(seq(from=-20, to=50, by=0.1)-(-0.5715)))), 
       type="l", col="orange", lwd=2, lty=2) #Insert the parameters found in the model manually

#fit VB growth model
x<-as.numeric(dataNO$LAG)
y<-as.numeric(dataNO$Pubis.radius..mm.)
vbTypical <- y~Linf*(1-exp(-K*(x-t0)))                                             # define Von Bertalanffy model
fitTypical <- nls(vbTypical,data=as.list(dataNO),
                  start=list(Linf=18, K=0.3, t0=1))                          # fit VB model to simulated data
fitTypical
points(x=seq(from=-20, to=50, by=0.1), 
       y=(20.3326)*(1-exp(-(0.1375)*((seq(from=-20, to=50, by=0.1))-(-3.3030)))), 
       type="l", col="orange", lwd=2, lty=4) #Insert the parameters found in the model manually

#fit logarithmic growth model 
x<-as.numeric(dataNO$LAG)
y<-as.numeric(dataNO$Pubis.radius..mm.)
model.zuriNO <- lm(y ~ log(x))
x=seq(from=-20,to=50,length.out=1000)
y=predict(model.zuriNO,newdata=list(x=seq(from=-20,to=50,length.out=1000)))
matlines(x,y, lwd=2, col='orange', lty=3)


####### ADD POINTS LAST
points(dataNO$LAG, dataNO$Pubis.radius..mm., cex=2, pch=16, col="orange")
points(data$LAG.number, data$Pubis.radius..mm., cex=2, pch=21, col="purple")

